@@ -7,11 +7,11 @@ Posy::Plugin::FindGrep - Posy plugin to find files using grep.
 
 =head1 VERSION
 
-This describes version B<0.20> of Posy::Plugin::FindGrep.
+This describes version B<0.21> of Posy::Plugin::FindGrep.
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ The number of entries which were found which matched the search parameter.
 =head2 Activation
 
 This plugin needs to be added to the plugins list and the actions list.
-Since this overrides the 'select_by_path' method, care needs to be
+Since this overrides the 'select_entries' method, care needs to be
 taken with other plugins if they override the same method.
 
 In the actions list 'findgrep_set' needs to go somewhere after
@@ -104,9 +104,9 @@ sub init {
 
 Methods implementing actions.
 
-=head2 select_by_path
+=head2 select_entries
 
-$self->select_by_path($flow_state);
+$self->select_entries($flow_state);
 
 If there is a 'find' parameter set, checks and uses the value as a regular
 expression to grep for files.  Uses the category directory given
@@ -120,7 +120,7 @@ Assumes that no entries have been selected before.  Sets
 $flow_state->{entries}.  Assumes it hasn't already been set.
 
 =cut
-sub select_by_path {
+sub select_entries {
     my $self = shift;
     my $flow_state = shift;
 
@@ -168,14 +168,14 @@ sub select_by_path {
 	}
 	else
 	{
-	    $self->SUPER::select_by_path($flow_state);
+	    $self->SUPER::select_entries($flow_state);
 	}
     }
     else
     {
-	$self->SUPER::select_by_path($flow_state);
+	$self->SUPER::select_entries($flow_state);
     }
-} # select_by_path
+} # select_entries
 
 =head2 findgrep_set
 
@@ -208,6 +208,74 @@ sub findgrep_set {
     1;
 } # findgrep_set
 
+=head1 INSTALLATION
+
+Installation needs will vary depending on the particular setup a person
+has.
+
+=head2 Administrator, Automatic
+
+If you are the administrator of the system, then the dead simple method of
+installing the modules is to use the CPAN or CPANPLUS system.
+
+    cpanp -i Posy::Plugin::FindGrep
+
+This will install this plugin in the usual places where modules get
+installed when one is using CPAN(PLUS).
+
+=head2 Administrator, By Hand
+
+If you are the administrator of the system, but don't wish to use the
+CPAN(PLUS) method, then this is for you.  Take the *.tar.gz file
+and untar it in a suitable directory.
+
+To install this module, run the following commands:
+
+    perl Build.PL
+    ./Build
+    ./Build test
+    ./Build install
+
+Or, if you're on a platform (like DOS or Windows) that doesn't like the
+"./" notation, you can do this:
+
+   perl Build.PL
+   perl Build
+   perl Build test
+   perl Build install
+
+=head2 User With Shell Access
+
+If you are a user on a system, and don't have root/administrator access,
+you need to install Posy somewhere other than the default place (since you
+don't have access to it).  However, if you have shell access to the system,
+then you can install it in your home directory.
+
+Say your home directory is "/home/fred", and you want to install the
+modules into a subdirectory called "perl".
+
+Download the *.tar.gz file and untar it in a suitable directory.
+
+    perl Build.PL --install_base /home/fred/perl
+    ./Build
+    ./Build test
+    ./Build install
+
+This will install the files underneath /home/fred/perl.
+
+You will then need to make sure that you alter the PERL5LIB variable to
+find the modules, and the PATH variable to find the scripts (posy_one,
+posy_static).
+
+Therefore you will need to change:
+your path, to include /home/fred/perl/script (where the script will be)
+
+	PATH=/home/fred/perl/script:${PATH}
+
+the PERL5LIB variable to add /home/fred/perl/lib
+
+	PERL5LIB=/home/fred/perl/lib:${PERL5LIB}
+
 =head1 REQUIRES
 
     Test::More
